ResponseHandler

Trait ResponseHandler 

pub trait ResponseHandler {
    // Required methods
    fn assert_200(&self);
    fn assert_201(&self);
    fn assert_204(&self);
    fn assert_400(&self);
    fn assert_401(&self);
    fn assert_403(&self);
    fn assert_404(&self);
    fn assert_409(&self);
    fn assert_500(&self);
}

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ResponseHandler for Response

Source

fn assert_200(&self)

Assertion that checks the response status code is 200

Source

fn assert_201(&self)

Assertion that checks the response status code is 201

Source

fn assert_204(&self)

Assertion that checks the response status code is 204

Source

fn assert_400(&self)

Assertion that checks the response status code is 400

Source

fn assert_401(&self)

Assertion that checks the response status code is 401

Source

fn assert_403(&self)

Assertion that checks the response status code is 403

Source

fn assert_404(&self)

Assertion that checks the response status code is 404

Source

fn assert_409(&self)

Assertion that checks the response status code is 409

Source

fn assert_500(&self)

Assertion that checks the response status code is 500

Implementors