pub trait ResponseHandler {
// Required methods
fn assert_200(&self);
fn assert_201(&self);
fn assert_204(&self);
fn assert_400(&self);
fn assert_401(&self);
fn assert_403(&self);
fn assert_404(&self);
fn assert_409(&self);
fn assert_500(&self);
}Required Methods
fn assert_200(&self)
fn assert_201(&self)
fn assert_204(&self)
fn assert_400(&self)
fn assert_401(&self)
fn assert_403(&self)
fn assert_404(&self)
fn assert_409(&self)
fn assert_500(&self)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl ResponseHandler for Response
impl ResponseHandler for Response
Sourcefn assert_200(&self)
fn assert_200(&self)
Assertion that checks the response status code is 200
Sourcefn assert_201(&self)
fn assert_201(&self)
Assertion that checks the response status code is 201
Sourcefn assert_204(&self)
fn assert_204(&self)
Assertion that checks the response status code is 204
Sourcefn assert_400(&self)
fn assert_400(&self)
Assertion that checks the response status code is 400
Sourcefn assert_401(&self)
fn assert_401(&self)
Assertion that checks the response status code is 401
Sourcefn assert_403(&self)
fn assert_403(&self)
Assertion that checks the response status code is 403
Sourcefn assert_404(&self)
fn assert_404(&self)
Assertion that checks the response status code is 404
Sourcefn assert_409(&self)
fn assert_409(&self)
Assertion that checks the response status code is 409
Sourcefn assert_500(&self)
fn assert_500(&self)
Assertion that checks the response status code is 500